#
# spec file for package kvantum
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt5%{nil}
%if "%{flavor}" == ""
ExclusiveArch:  do_not_build
%endif
%if "%{flavor}" == "qt6"
%define qt6 1
%define pkg_suffix -qt6
%define dsc_suffix Qt6
%endif
%if "%{flavor}" == "qt5"
%define qt5 1
%define pkg_suffix -qt5
%define dsc_suffix Qt5
%endif
Name:           kvantum%{?pkg_suffix}
Version:        1.1.3
Release:        1.2
Summary:        SVG-based theme engine for Qt5 and Qt6
License:        GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            https://github.com/tsujan/Kvantum
Source0:        https://github.com/tsujan/Kvantum/archive/V%{version}.tar.gz#/kvantum-%{version}.tar.gz
BuildRequires:  cmake
%if 0%{?qt5}
BuildRequires:  kwindowsystem-devel
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  cmake(Qt5Core) > 5.15
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
%endif
%if 0%{?qt6}
BuildRequires:  fdupes
%if 0%{?suse_version} > 1600
BuildRequires:  kf6-kwindowsystem-devel
%endif
BuildRequires:  qt6-linguist-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Svg)
%endif

%description
Kvantum is an SVG-based theme engine for Qt, tuned to Plasma and LXQt, with an emphasis on elegance, usability and practicality.
Its homepage is https://github.com/tsujan/Kvantum.

Kvantum also comes with extra themes that can be selected and activated by using Kvantum Manager.

This package provides Kvantum theme engine for %{dsc_suffix}.

%package -n kvantum-manager
Summary:        GUI for installing, selecting and manipulating Kvantum themes
Requires:       kvantum-qt6 = %{version}

%description -n kvantum-manager
This package provides configuration manager - GUI appligation for installing, selecting and manipulating Kvantum themes.

%package -n kvantum-manager-lang
Summary:        Translations for Kvantum manager
Requires:       kvantum-manager = %{version}
BuildArch:      noarch

%description -n kvantum-manager-lang

This package provides translations for Kvantum manager.

%package -n kvantum-doc
Summary:        Documentation for Kvantum engine
BuildArch:      noarch

%description -n kvantum-doc
This package provides instructions on how to change configuration or make new themes for Kvantum engine.

%package -n kvantum-themes
Summary:        Themes for Kvantum engine
Requires:       (kvantum-qt6 = %{version} or kvantum-qt5 = %{version})
BuildArch:      noarch

%description -n kvantum-themes

This package provides extra themes for Kvantum engine.

%package -n kvantum-openbox-themes
Summary:        Openbox themes for Kvantum engine
BuildArch:      noarch

%description -n kvantum-openbox-themes

This package provides extra Openbox themes for Kvantum engine.

%prep
%setup -q -n Kvantum-%{version}

%build

pushd Kvantum
%if 0%{?qt5}
%cmake -DENABLE_QT5=ON
%cmake_build
%endif
%if 0%{?qt6}
%if 0%{?suse_version} > 1600
%cmake_qt6
%else
%cmake_qt6 -DWITHOUT_KF=ON
%endif
%{qt6_build}
%endif

%install
pushd Kvantum
%if 0%{?qt5}
%cmake_install
%endif
%if 0%{?qt6}
%{qt6_install}
%endif

%if 0%{?qt6}
%fdupes %{buildroot}%{_datadir}/themes
%suse_update_desktop_file kvantummanager Utility Settings DesktopSettings X-XFCE-SettingsDialog X-XFCE-PersonalSettings X-GNOME-PersonalSettings
%endif

%files
%dir %{_libdir}/%{flavor}/plugins/styles
%{_libdir}/%{flavor}/plugins/styles/*
%license Kvantum/COPYING
%doc Kvantum/README.md

%if 0%{?qt6}
%files -n kvantum-manager
%{_bindir}/*
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/applications/kvantummanager.desktop
%{_datadir}/icons/hicolor/scalable/apps/kvantum.svg

%files -n kvantum-manager-lang
%dir %{_datadir}/kvantummanager
%dir %{_datadir}/kvantumpreview
%dir %{_datadir}/kvantummanager/translations
%dir %{_datadir}/kvantumpreview/translations
%{_datadir}/kvantummanager/translations/*
%{_datadir}/kvantumpreview/translations/*

%files -n kvantum-doc

%doc Kvantum/doc/*

%files -n kvantum-themes
%exclude %{_datadir}/kde4/apps/color-schemes/*
%dir %{_datadir}/color-schemes/
%dir %{_datadir}/Kvantum
%dir %{_datadir}/Kvantum/Kv*
%{_datadir}/color-schemes/*
%{_datadir}/Kvantum/Kv*/*
%endif

%changelog
* Thu Oct 24 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.1.3
  * Qt 6.8.0 has a regression that randomly creates artifacts in
    translucent windows under Wayland. A workaround has been added for
    it, such that the windows/menus/tooltips which are made translucent
    by Kvantum are not affected by it.
  * Dragged tabs of Qt ≥ 6.6 are drawn as single tabs (like they were
    drawn with Qt < 6.6).
  * Bumped the minimum required version of Qt6 to 6.6.
  * Said goodbye to KF5. Since the current version, the Qt5 plugin
    is compiled without it (which means no blurring for Qt5 apps under
    Wayland).
  * Updated and cleaned up the code.
* Mon Jun 10 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.1.2
  * Followed Qt 6.7 by giving all available space to text rectangles
    of view items (fixes a regression with Qt ≥ 6.7).
  * Workaround for an inconsistency in Qt, where a persistent editor
    can be opened for an uneditable view item.
* Thu May 16 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.1.1
  * A workaround is added for a backward incompatible change in how
    Qt 6.7 draws item views.
  * Fixed an old issue in drawing radio buttons under mouse cursor
    without animation.
  * The support for qmake is back but without KWindowSystem (and
    without being advertised).
* Sun Mar 17 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.1.0
- update spec for default Qt6
- use kwindowsystem only for TW for now
  * The default compilation is against Qt6 now (For Qt5, ENABLE_QT5
    should be set to ON), and the support for qmake has been removed
    (because KF6 doesn't support it). The blur effect of KWin 6.0 is supported.
  * It is possible to reduce only the opacity of inactive windows
    with negative values of the relevant setting (in Kvantum Manager).
  * Added a workaround for a bug in Qt 6.6, because of which,
    translucent menus might be drawn with wrong sizes after being moved.
  * Added a workaround for tiny overlaps between tree branch lines
    with translucent light/dark colors.
  * Added a workaround for a crashing bug in KDE's plasma-settings.
  * Added a toolbar, containing a date-time editor with popup and a
    progress-bar, to kvantumpreview.
  * Minor fixes.
* Tue Apr 25 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Remove kvantum-openbox-themes package
- Version 1.0.10
  In addition to better drawing of some widgets,
  * To support Qt5 long after Qt6 becomes the default, compilation
    without KDE Frameworks is made possible (if it is used, KWin's
    blur effect will be available only under X11). It works with Qt6 too.
  * Rounded buttons, combo-boxes and line-edits are allowed in LibreOffice.
  * Openbox themes are removed (Openbox's development stopped years ago).
    If you use Openbox, you could import its themes from older
    versions of Kvantum at GitHub.
- Version 1.0.9
  * Fixed a regression that caused crashes in QML apps and LibreOffice
    when the widget animation was disabled.
  * Also, a workaround is added for a rare case, where a bad code
    gives an enormous contents size to item-views.
- Version 1.0.8
  Main changes:
  * Dragging of inactive windows of multi-window apps is fixed under
    Wayland.
  * Wide combo menu icons are taken into account.
  * QML indeterminate progressbars are animated (when qqc2-desktop-style
    is used).
  * Small workarounds, especially under Wayland.
* Thu Mar 16 2023 Antonio Larrosa <alarrosa@suse.com>
- Use qt6_build macros to fix build in SLE15 SP5
* Wed Mar 15 2023 Max Lin <mlin@suse.com>
- Fix a typo in kvantum-themes dep-requirement
  * Change kvanum-qt5 to kvantum-qt5
* Thu Dec  1 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.7
  * Don't rely on the (undocumented) "Destroy" event to remove
    destroyed widgets from lists. In this way, the cause of a rare
    crash is removed.
  * Better guarantee for the lack of scrollbars in the config page
    of Kvantum Manager when it's visited for the first time.
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- another fixes in naming
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Proper naming
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update Summary
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- fix build Qt6 version for 15.4
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- simplify conditions
* Wed Nov 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- use singlespec muiltibuild
* Tue Nov 22 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- attempt to multibuild
* Tue Nov 22 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.6
  * Added workarounds for Kate's new side-pane and status-bar buttons
    (which still have wrong style codes).
  * Silenced the compilation warnings with Qt 6.4.
* Wed Sep 21 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.5
  - Added a workaround for a new bug in Krita 5.1.0 (which could
    make Krita freeze if a Kvantum theme requested a progress-bar
    height greater than that of Fusion).
  - Also, added safeguards against two kinds of wrong app codes.
  - Added a condition for window dragging under Wayland, especially
    for dragging from buttons.
  - Simplified finding of Qt modules with cmake.
* Mon Aug  8 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Verion 1.0.4
  - Added a workaround for Qt6's double click problem with window dragging.
  - Added a workaround for Qt6's window dragging when the cursor
    is outside the widget after the drag is finished (previously,
    its hover state would persist).
  - Don't start window dragging if a popup menu is shown and
    closed quickly (may happen very rarely).
  - Added 1px to button arrow margin.
  - Considered more details in drawing menu arrows of buttons
    (especially when QToolButton is null).
  - Removed button contents shift (it was useless and inconsistent).
  - Added a pushbutton with menu to kvantumpreview.
  - To find the sunken button that has triggered a menu, check whether
    that menu really belongs to it.
  - Improved the workaround for Qt's hover bug in buttons.
  - Made menu shortcuts a little paler than menu texts.
  - Added a workaround for LibreOffice's header view.
  - Removed the old HDPI workaround.
* Thu Jul  7 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.3
  - Fixed drawing of large label images that don't fit in the
    available space.
  - Prevented redundant updates of frameless scroll-areas.
  - Changed the default layout spacing to 3px.
  - Set the minimum contents height of tabs to 16px.
  - Added workarounds for stylesheet interference in spin-boxes.
  - Disabled "ChangeSelectionColor" in all KDE color schemes.
* Wed May 18 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.2
  - Added "widgets" to "style.pro" for Qt ≥ 6.2.4.
  - Don't set the active/inactive palettes of item views (when they
    are shown/activated/deactivated) if the inactive state is ignored.
  - Force palettes (of item views) on event filtering only if needed.
  - Apply blurring to the whole rectangles of menus/tooltips that
    aren't drawn by Kvantum.
  - Workarounds for issues in LibreOffice's Qt skin (guarantee
    opaque backgrounds for LibreOffice's spin-boxes and editable
    combo-boxes, work around bugs in tab positions, and give enough
    space to tabs and spinboxes).
  - Allow translucency in Qt widgets with LibreOffice.
  - Added a workaround for QML tool buttons.
  - Added a warning dialog that shows up when the user enables
    kinetic scrolling.
* Tue Mar  8 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.1
  - The minimum required version of Qt is bumped to 5.15.0 and that
    of KF5 to 5.82.0, thus openSUSE/SLES 15.3 is not supported anymore.
  - A workaround is added for the wrong style code of
    KisDoubleSliderSpinBox in Krita ≥ 5.0.0.
  - Options are added (to Kvantum Manager) for setting corner radii
    when blurring translucent menus and tooltips with rounded corners.
    Usually, a value of 2 is enough for preventing blur artifacts.
  - 16px is given to the width of vertical spinbox buttons.
  - Small fixes.
* Fri Jan  7 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Disable 32-bit builds for x86_64
* Mon Dec 20 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 1.0.0
  - Enabled experimental compilation of Kvantum's plugin against Qt6.
    With cmake, "ENABLE_QT5" should be set to "OFF" (as in `cmake ..
  - DENABLE_QT5=OFF`) — it's "ON" by default.
  - A little more precise calculation of sizes of buttons with bold texts.
  - Take "ToolButtonFollowStyle" into account when getting the style
    from the toolbutton itself (a logical consideration with no effect).
  - Added a workaround for missing panels and frames of LibreOffice's
    input fields.
  - Made Kvantum Manager a little more keyboard friendly.
  - Ensure that the left mouse button is pressed on starting window
    dragging (it may not be pressed in very rare cases, where a popup
    is shown after moving the cursor and closed before dragging).
  - Added a variant of KvCurves3d with light selection color.
  - Derive the disabled highlighted text color from the active
    highlighted text color.
  - Consider the mouseover state for icons of check boxes and radio
    buttons if relevant.
  - Added an example of progress-bar inside view-item to kvantumpreview.
  - Added a workaround for KWin-Wayland's menus and tooltips (they're
    polished before the platform name is set to "wayland").
  - Added an option (to Kvantum Manager) for not blurring inactive windows.
  - Removed the workaround fo the fixed Qt5 bug QTBUG-47043 but added
    another workaround for a similar Qt6 bug.
  - Limit the transparency of PCManFM-Qt's view to its main window.
* Wed Sep 15 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.20.2
  - Respect KDE's scrollbar click behavior by default.
  - Elide push button text if there isn't enough space for it.
  - Allow opening of the user config file from Kvantum Manager.
  - Added LibreOffice to the black list of window dragging (as a
    workaround for issues related to its Qt5 skin under Wayland).
* Thu Aug 12 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.20.1
  - Blacklisted QQuickWidget with window dragging.
  - Made the workaround for bad hard-coded styles of line-edits less strict.
* Mon May 31 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.20.0
  - Fixed drawing of view-items with right-aligned decorations.
  - Added an option for always centering normal tabs (in contrast to the document mode).
  - Added an option (to Kvantum Manager) for styling vertical toolbars.
  - Fixed a small problem in tab overlapping.
  - Don't allow kinetic scrolling inside subwindows.
  - Used version check for KWindowSystem because of method deprecations.
  - Dropped support for Qt5 < 5.12.
* Thu Mar 25 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.19.0
  - Fixes and improvements to window dragging, especially from buttons.
  - Added an option (to Kvantum Manager) for setting the toolbar
    icon size to the font height if possible (it's the special value
    of Kvantum Manager → Configure Active Theme → Sizes & Delays → Toolbar icon:).
  - Better drawing of view-items.
  - Fixed a rare problem in transient scrollbars.
* Tue Jan  5 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.18.0
- The main feature of this release is a better window dragging
  with Qt ≥ 5.15. It works under X11 and Wayland alike by calling
  the window manager correctly. It also allows dragging from
  buttons (with an option in Kvantum Manager).
- Some other changes:
- Fixed the centered form layouts.
- Made toolbars unmovable by default.
- Better widths for push buttons, tabs and menus.
- Draw the icon of a menubar item instead of its text if it's
  given.
- A new theme is added (KvMojaveMixed1, a variant of KvMojaveMixed)
  and some themes are polished.
- Removed the scroll jump workaround. It interfered with
  animations and cluttered the code to partially compensate for
  a Qt bug.
* Sat Oct  3 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.17.0
- Also, take care of widgets without interior SVG elements on a menu
  that has a high contrast with the window (a possible scenario that
  hasn't happened with any theme so far).
- A workaround for a rare problem in QWidgetAction when menus have
  a high contrast with windows.
- Fixed the text color of thin progressbars inside stylable toolbars
  of dark-and-light themes.
- More accurate calculation of spinbox width under special
  circumstances.
- Distinguish popup indicators from other button indicators on
  mouseover.
* Mon Aug 10 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.16.1
- More explicitness about the color group when getting colors from the standard panel. This fixes a small problem in inactive line-edits of some themes.
- Made the toolbar of recent versions of Krita stylable.
* Wed Jun 24 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.16.0
- Set the scroll indicator size of tabs to that of toolbar buttons.
- Fixed a rare issue in the frame size of grouped elements.
- Added an option to Kvantum Manager for enabling window translucency with non-integer scale factors after showing a warning.
- A workaround for a rare case of Qt's contradicting QStyle in drawing spin boxes.
- Fixed the height of combo menu separators.
- Reset widget palettes on changing style from and to Kvantum. This fixes several problems with on-the-fly style changes, so that an app restart won't be needed in most cases.
- Updated the code for Qt 5.15.
- Added a workaround for a regression in Qt 5.15, which results in QStyleOptionTab reporting an incorrect tab position.
* Wed May 13 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.15.3
- Better calculations for progressbars.
- Aligned a menu-item's text with others' if its icon isn't null but its pixmap is.
- Added a workaround for a small issue in the toolbar timer of Audacious 4.0.
- Removed old stuff from installation.
* Sun Apr  5 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.15.2
- When compensating for menu shadows, consider the cursor position as the last resort.
- Consider RTL in QCommandLinkButton (although Qt doesn't).
* Wed Mar 18 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.15.1
- Fixed a crash in Kleopatra's settings dialog.
- Added some dialog button icons for Qt ≥ 5.14.
* Wed Mar 11 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.15.0
- Added an option (to Kvantum Manager) for horizontally centered forms.
- Handled the device pixel ratio more locally — because, apparently, Wayland can give different pixel ratios to different screens.
- Added KvMojaveMixed, a version of KvMojaveLight with dark menubar and primary toolbar.
- Added a workaround for codes that change a line-edit's base color (like in Kate and Konsole).
- Don't set WA_NoSystemBackground with hard-coded translucency. (This solves the problem of Konsole's transparent menubar with some translucent themes.)
- Milder gradient for menus of the default theme.
* Mon Jan 13 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.14.1
- Enforce contrast between symbolic clear icon and background of toolbar lineedits in dark-and-light themes if possible.
- Consider the size of lineedit clear icons to be PM_SmallIconSize.
* Sun Dec 29 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.14.0
- Prevent toolbar arrow on showing kvantumpreview.
- Guarantee correct symbolic icon colors for combos inside toolbars.
- Don't let combo menus have a greater height that ordinary menus (Qt increases their height).
- Never change the palette of toolbar buttons/combos/line-edits that are within a separate window.
- Allow custom elements for focus rectangles of some widgets.
- Removed the redundant key "no_focus_rect".
- Safeguard against a badly edited kvconfig file when writing to it with Kvantum Manager.
- Added a (temporary) workaround for a nasty bug about text translucency in Qt 5.14.0.
- Handle PlaceholderText with Qt ≥ 5.12.-
* Mon Dec  9 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.13.0
- In tab size calculation, consider the actual tab icon size instead of PM_TabBarIconSize if it exists.
- Don't decrease the minimum size of a spinbox if it's more than enough for its text.
- Don't avoid elided texts in task buttons of LXQt Panel.
- Added a key for the thickness of toolbar separators.
- Ensure correct menu blurring if the compositor starts with a short delay.
- Prevent menus from switching to another screen with a multi-screen setup.
  - obsoletes 01-Prevent-menus-from-switching-screen-with-multi-screen-setup.patch
- Avoid scrollbars in the third page of Kvantum Manager the first time it's shown.
- Put menubar MDI buttons inside menubar frame.
- Don't show the arrow of a tool button with instant popup.
- Fixed an old problem in toolbars of dark-and-light themes.
- A safeguard against buggy Qt plugins that don't handle the tool-button style correctly. (So far, only qt5ct has had bugs.)
* Fri Nov  8 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- -add patch from upstream:  01-Prevent-menus-from-switching-screen-with-multi-screen-setup.patch
* Thu Oct 17 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- Version 0.12.1
  - Added a hacking option for kinetic scrolling to Kvantum Manager. Although Qt's kinetic scrolling has bugs, it doesn't cause crashes with Qt ≥ 5.13.1.
  - Fixed problems in updating the GUI of Kvantum Manager on theme change.
* Wed Oct  9 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- Restored Qt4 compilation
* Wed Oct  2 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- A workaround for a Qt bug that causes drawing problems with non-integer scale factors. They can be seen with Fusion too but become intense with window SVG gradient and/or translucency.
- Avoid ugly backgrounds behind menu scroller arrows.
- Forcefully prevent stylesheets from ruining combo menus.
* Wed Sep 25 2019 Konstantin Voinov <kv@kott.no-ip.biz>
- Ignore the disabled state of tree expanders (because some apps, like Dolphin, don't set the state to enabled).
- Removed the wayland menu translucency workaround for Qt ≥ 5.12.
- When giving a transparent background to QComboBoxPrivateContainer with combo menus, create the transparency by setting the alpha of the real background color to zero. This works around the problem in Lyx's combo menu.
- Milder gradient for the default theme's tab frame interior.
* Mon Sep 16 2019 Konstantin Voinov <kill_it@mail.ru>
- A workaround for the bug in Qt 5.13.1 → QWidget::setAttribute(), when the app style is changed.
* Fri Sep  6 2019 Konstantin Voinov <kill_it@mail.ru>
- Added a new option for the click behavior with 3 values for following the current DE or using single or double click (and removed the old click option).
* Mon Aug 26 2019 Konstantin Voinov <kill_it@mail.ru>
- Basic support for FreeBSD.
-Version 0.11.2
* Mon Aug 26 2019 Konstantin Voinov <kill_it@mail.ru>
- Added a key (to Kvantum Manager) for removing all focus rectangles.
- Disable the context menu for transient scrollbars (because of the hover bug in Qt5).
* Fri Jul 12 2019 Konstantin Voinov <kill_it@mail.ru>
- Added a low-contrast theme (KvBlender) inspired by Blender.
- Added a key to remove extra generic frames that some apps may draw.
- Also consider the "disabled" state when drawing rounded frames with separate expanded frame elements (it's used by progressbar indicator).
- Exclude toolbars whose appearances are modified by stylesheets from stylable toolbars.
- Don't animate the state change of generic frames if there is no top focused frame (to prevent probable flashes).
- When removing translucency from the base color in special cases, also consider the window color behind it.
- Make the alternate base color opaque by applying it over the base color because some apps may ignore its translucency.
- No disabled state for toolbars because, otherwise, it would be both ugly and useless.
- Prevent tiny busy indicators with rounded progressbars.
- More precise calculations related to shadows and blurring of menus/tooltips, especially for preventing 1-px blurred strips outside menu/tooltip borders.
- Replaced the Qt methods that were deprecated by Qt 5.13.
* Wed Jun  5 2019 Konstantin Voinov <kill_it@mail.ru>
- Fixed toolbar horizontal extension indicator with HDPI.
* Wed May 22 2019 Konstantin Voinov <kill_it@mail.ru>
-Version 11.1
-  Use native file dialog in Kvantum Manager.
- Since HDPI is supported by KDE's blur effect with Qt ≥ 5.12, disable Kvantum's workaround for those versions.
- Explicitly set the minimum Qt version to 5.9.0.
- Use QStringLiteral with DATADIR (otherwise, some compilers might get confused).
* Thu May  2 2019 Konstantin Voinov <kill_it@mail.ru>
- Added the missing disabled state of dials.
- Since HDPI is supported by KDE's blur effect with Qt ≥ 5.12, disable Kvantum's workaround for those versions.-
* Tue Apr 16 2019 Konstantin Voinov <kill_it@mail.ru>
- Removed redundant computations after showing a menu. Their results are remembered instead.
* Fri Apr 12 2019 Konstantin Voinov <kill_it@mail.ru>
- Don't force bold or italic font on combo or menu-item texts (because finding longest texts of combos isn't CPU-friendly and combos can have menu popups).
- Ignore window frame with dragging (less calculation for Qt and no jump under Enlightenment).
- Set QStyle's standard palette to the Kvantum theme palette and make use of it instead of app palette (because app palette may not be reliable with some apps, like Qt Designer).
- An effective way of finding menus that aren't drawn by kvantum before showing them (for not moving them to compensate for their shadows, which don't exist).
* Wed Apr  3 2019 Konstantin Voinov <kill_it@mail.ru>
- Added a key for removing Kvantum shadows from composited menus and tooltips (under DEs that give them shadow).
- Fill opaque combo menus with the window color (because transparency is enforced on combo menus while polishing them).
- When spreading menuitems across menus, do it for non-composited menus too.
- Always integrate the drop-down part of a combo box if it's drawn as a lineedit.
- Keep (partial) frame expansion as far as possible (previously, it was removed in all special cases).
- Remember whether some elements exist in the SVG file, instead of searching for them again and again.
- Imported QCommonStyle's combo width calculation (with no change in the final result).
* Fri Mar 29 2019 Konstantin Voinov <kill_it@mail.ru>
- Don't enforce window size grip with fixed size layouts.
* Sun Mar 24 2019 Konstantin Voinov <kill_it@mail.ru>
- No separator between toggled and pressed grouped toolbuttons.
* Sat Mar 23 2019 Konstantin Voinov <kill_it@mail.ru>
-Version 0.11.0
- Paint QCommandLinkButton completely in the code (panel + icon + texts) to remove discrepancies between it and other kinds of buttons.
- Don't rotate the toolbar handle on vertical toolbars if it's centered-
* Thu Mar 21 2019 Konstantin Voinov <kill_it@mail.ru>
- Changed the drag cursor from drag-move to open-hand.
- Don't draw title-bar icons on subwindow menu if there isn't enough contrast.
- Always integrate the drop-down part of a tool button (not only when it has frame expansion).
- Fixed the text alignment of QCommandLinkButton and added a workaround for the color Qt gave to its text.
* Wed Mar  6 2019 Konstantin Voinov <kill_it@mail.ru>
- Also check the active action of active popup when determining whether a submenu is going to be shown.
- Added a key for drawing the spinbox separator also with inline indicators.
- Changed KvGnome for it to match the latest default GTK+ theme.
* Fri Feb 22 2019 Konstantin Voinov <kill_it@mail.ru>
- Don't move a menu that isn't drawn by kvantum (when a menu is drawn by a stylesheet, Qt lets QStyle polish it; hence the problem).
- Reversed the above-mentioned workaround for now because, unfortunately, Qt doesn't provide a reliable way of distinguishing stylesheet menus at the moment they're shown.
- Don't move detached menus when they're shown.
- Support LibreOffice's new Qt5 skin (that's much better than the old Qt4 skin).
* Sun Feb 10 2019 Konstantin Voinov <kill_it@mail.ru>
-Version 0.10.10
- Don't move a menu that isn't drawn by kvantum (when a menu is drawn by a stylesheet, Qt lets QStyle polish it; hence the problem).
* Sun Feb 10 2019 Konstantin Voinov <kill_it@mail.ru>
- Don't move a menu twice to compensate for its shadow width (it happens with LXQt main menu after a style change).
- Dropped QDesktopWidget.
- No redundant space for groupboxes without text/checkbox.
- Left mouse button sets slider position (middle button was a bad default).
* Wed Jan  9 2019 Konstantin Voinov <kill_it@mail.ru>
- Use QStringLiteral when appropriate.
- When blurring backgrounds of unusual tooltips, don't exclude the tooltip shadow width if they inherit QFrame.
- Check the widget mask in BlurHelper too and disable blurring if it isn't the widget rectangle. The reason is that the mask can be set after polishing.
- Align texts vertically centered when they aren't drawn by Kvantum directly.
* Tue Dec 11 2018 Konstantin Voinov <kill_it@mail.ru>
- Fixed a mistake in calculating combo box widths (the existence of icons wasn't considered correctly).
- Enforce the menu-item text color on font combo popups when needed.
- Fixed drawing of buttonless spin-boxes.
* Wed Dec  5 2018 Konstantin Voinov <kill_it@mail.ru>
- Added SVG symbolic icons to Kvantum Manager because the system symbolic icons didn't change their color when the theme was changed from light to dark or conversely.
- 3-px margin for centered toolbar handles.
* Thu Nov 29 2018 Konstantin Voinov <kill_it@mail.ru>
- Support the KDE contrast effect with Qt ≥ 5.11 for windows that support the blur effect (the KDE blur effect itself can be disabled).
- Make libfm-qt's path buttons follow group_toolbar_buttons.
- Consider active_tab_overlap in drawing tab-bar frames (because the active tab interior should be opaque when there's an overlap).
- Don't give too much space to text shadows.-
* Thu Nov 22 2018 Konstantin Voinov <kill_it@mail.ru>
- Made big menus scrollable by default.
* Mon Nov 19 2018 Konstantin Voinov <kill_it@mail.ru>
- Added an option (to Kvantum Manager) for setting the dialog button layout.
* Fri Nov 16 2018 Konstantin Voinov <kill_it@mail.ru>
- Animation for tab close buttons.
* Tue Nov  6 2018 Konstantin Voinov <kill_it@mail.ru>
- Maximum precision in drawing tree branch lines.
- Show menus of menubar items exactly below them, without a gap.
- Removed text shadow depths > 1 until Qt supports a better way of adding text shadows with QPainter.
- Added a workaround for Qt scroll jump with mouse gestures (as a hacking option in Kvantum Manager).
* Wed Oct 24 2018 Konstantin Voinov <kill_it@mail.ru>
- Depend on KWindowSystem (KWindowEffects) with Qt >= 5.11 to support the blur effect under Wayland too.
* Mon Oct 15 2018 Konstantin Voinov <kill_it@mail.ru>
- Support non-integer scale factors with HDPI.
- If the current theme is customized, go to its root version after it's removed by Kvantum Manager.-
* Thu Oct  4 2018 Konstantin Voinov <kill_it@mail.ru>
- No toggled state for progress bars.
- Made the X11 drag independent of X11 by using the QWindow method "setFramePosition()". The reason was a new bug in X11 codes of Qt5.11, which had damaged the X11 drag.-
* Wed Sep 26 2018 Konstantin Voinov <kill_it@mail.ru>
- Fixed an old bug in text shadows.
- Added a key for spreading menuitems across left and right menu frames.
- Added KvMojave.
* Tue Sep 25 2018 Konstantin Voinov <kill_it@mail.ru>
- Fixed a flaw in size calculations related to thin progressbars.
- Take care of thin progressbars with an expanding vertical policy.
- KvYaru is added and KvCommunitheme is removed.
- Fixed Dock specific close and restore buttons.
- Made dock splitters like other ones (by setting PM_DockWidgetSeparatorExtent) and dealt with too tall splitters.
- Optional separators for toggled buttons in grouped toolbar buttons.
* Thu Sep 13 2018 Konstantin Voinov <kill_it@mail.ru>
- Fixed QToolBox with HDPI.
- Don't let the text of an ordinary progressbar intersect its frame.
- Don't draw the left or right frame of a toolbar that is attached to the menubar but doesn't have the same width.
- Don't remove the frame expansion of view-items only because they are grouped together.
- Don't make windows translucent or blurry if they have partial masks.
- Fixed toolbar/menubar extension arrows with HDPI.
- Fixed a bug that prevented active tab overlapping when tab separators existed but "no_active_tab_separator" was "true".
- Added the key "center_scrollbar_indicator" for having a scrollbar-slider grip with the same width and height.
* Wed Sep 12 2018 Konstantin Voinov <kill_it@mail.ru>
- Version 0.10.9
- Group libfm-qt's path buttons when they aren't on a toolbar.
- Style the split view of pcmanfm-qt appropriately when its view is transparent.
* Mon Sep  3 2018 Konstantin Voinov <kill_it@mail.ru>
- Fixed QToolBox with HDPI.
- Don't let the text of an ordinary progressbar intersect its frame.
* Mon Aug 27 2018 kill_it@mail.ru
- Group libfm-qt's path buttons when they aren't on a toolbar.
- Style the split view of pcmanfm-qt appropriately when its view is transparent.
* Tue Aug 14 2018 kill_it@mail.ru
- Fill the menu interior with the window background color if there isn't an interior SVG element.
- Gave meaning to min_height/min_width under Window and Dialog sections by making them the minimum height/width of the background (interior) SVG element (useful with gradients).
* Tue Aug  7 2018 kill_it@mail.ru
- When searching for a stylable toolbar container, search only in the direct children of the widget's window.
- Find exact heights of multi-line texts for all kinds of fonts by finding their bounding rectangles and without resorting to any "magic constant".
- Added the key "spread_header" for making simple headers. Also, RTL headers are fixed.
- Added "inactive.alt.base.color" because alternate rows are drawn by Kvantum now.
- Corrected RTL for QToolBox (a bug in QCommonStyle).
- Consider inactiveness in setting scrollbar background.
- If a combo isn't styled by Kvantum anymore, don't restore its item delegate (otherwise, a rare crash might happen).
- Fixed the header icon position with RTL layouts.
- Merge the background of a header with that of its parent view, if any.
* Wed Aug  1 2018 kill_it@mail.ru
- Version 0.10.8
- Try to support translucent base colors, knowing that it isn't possible in all cases.
- Changed old-style casts to C++ ones.
* Wed Aug  1 2018 kill_it@mail.ru
- Enable window translucency under Wayland because Qt >= 5.11 supports it.
* Wed Jul 18 2018 kill_it@mail.ru
- Added command-line options to kvantummanager.
* Fri Jul  6 2018 kill_it@mail.ru
- Split "Kvantum.cpp" logically.
- Added a key (to Kvantum manager) for reducing menu opacity.-
* Mon Jul  2 2018 kill_it@mail.ru
- Vertically center textless slim (horizontal) progressbars.
* Tue Jun 19 2018 kill_it@mail.ru
- Added a key (to Kvantum manager) for ignoring the inactive state.
- For an exact vertical centering, give an even height to the bounding rectangle of the text and the icon beside it.
- Consider special fonts for menu-items (some apps may use them to show different things).
- Added a key (to Kvantum Manager) for removing (text) color translucency.
* Mon Jun  4 2018 kill_it@mail.ru
- Added a key for menu separator height.
* Thu May 31 2018 kill_it@mail.ru
- Added the optional section ScrollbarTransientSlider.
- Compensate for a change in the vertical positioning of submenus with Qt 5.11.
* Fri May 11 2018 kill_it@mail.ru
- Smoother movement of dial handle.
* Mon May  7 2018 kill_it@mail.ru
- Don't enforce vertically centered labels for comboboxes and line-edits.
- Consider the top and bottom label spacings when drawing some indicators.
* Fri May  4 2018 kill_it@mail.ru
- Optional sections for line-edits and combo-boxes inside toolbars.
* Tue Apr 24 2018 kill_it@mail.ru
- Cover a very rare case, where the special text of a spinbox is set when its value is minimum (which means a bad code).
- Center menubar-item texts horizontally (they were left-aligned before).
- Added a workaround for an old Qt bug which, sometimes, prevents updating of inactive widgets when the active and inactive highlight colors are the same.
- Handle multi-line combo-box menu-items by drawing them on a single line.
* Thu Apr 12 2018 kill_it@mail.ru
- Version 0.10.7
- Removed the workaround for Gwenview's scrollbar issue because it was potentially dangerous (actually, just in one case). Anyhow, Gwenview's bug was fixed a long time ago.-
* Tue Apr 10 2018 kill_it@mail.ru
- Optionally separate checkboxes in view-items.
- Updated RTL header drawing because of a recent change (or issue?) in Qt5.
- Standardized the color contrast calculation according to "Web Content Accessibility Guidelines".
* Wed Apr  4 2018 kill_it@mail.ru
- Added a key for bold active tab text.
- Added a key for the degree of boldness (from 1 to 5; 3 means normally bold).
- An optional "-tickless" element for the slider handle when the slider has no tick marks.
* Wed Mar 28 2018 kill_it@mail.ru
- Limit the menu check/redio box size to the small icon size and not to what QCommonStyle returns.
* Wed Mar 21 2018 kill_it@mail.ru
- Added a workaround for "selectable disabled view items" (Qt Creator can have such items with cmake projects).
* Mon Mar 19 2018 kill_it@mail.ru
- Fixed inactive states of nonstandard buttons.
- A workaround for badly designed progressbars (as in pavucontrol-qt -- I didn't fix pavucontrol-qt because other developers might make the same mistake).
- Reverse the new default behavior of Qt5 submenus, due to which, submenus are closed when the cursor leaves all menus.
- Handle disabled icons so that they're always dim (even with KDE icon engine, which doesn't call generatedIconPixmap() with SVG symbolic icons);
* Sun Mar 11 2018 kill_it@mail.ru
- Don't draw the interior of the focus rectangle but allow complete focus elements on the whole widget (button like widgets, tabs, group boxes and sliders are supported), so that if their names exist in the config file, their elements will be drawn inst
  ead of the focus rectangle.
- Don't rotate a rounded frame unless it has a top expanded (or border) element.
- Added a key for an extra margin between tab frame and tab button.
- Added a 3px spacing between the top text of a groupbox and its top frame.
- Added optional icon/arrow separators for comboboxes in edit mode.
- Added a key for square arrow buttons in editable combo boxes. It also removes the combo panel behind the icon.
- Put the texts of thin progressbars above them as far as possible. If there isn't enough space above a thin progressbar, put its the text in front of it.
* Wed Feb 28 2018 kill_it@mail.ru
- Fixed the disabled text color of auto-raised toolbuttons in dark-and-light themes.
* Mon Feb 26 2018 kill_it@mail.ru
- Fixed an old miscalculation in drawing tab labels.
- Major enhancements and simplifications in the state change animation code through "QStyleOption::styleObject()". As a result, faulty animations are fixed and some missing animations are added, especially for all kinds of buttons.
* Mon Feb 19 2018 kill_it@mail.ru
- Support the global config files /usr/local/etc/xdg:/etc/xdg/Kvantum/kvantum.kvconfig. (For distros.)
* Mon Feb 12 2018 kill_it@mail.ru
- Handle the CMP0071 policy of CMAKE >= 3.10 (let AUTOMOC and AUTOUIC process GENERATED files).
- Make combo_focus_rect use the normal panel to draw a combo box with the keyboard focus.
- A workaround for a Qt5 mess in painting the "clear" button of line-edits (the issue is visible in Fusion too).
- Remove "foreach" with Qt5.
- Don't add the icon size to the size of check boxes or radio buttons when there's no icon.
- Replaced QRegExp with QRegularExpression.
* Mon Nov 20 2017 kill_it@mail.ru
- Added a hacking key (to Kvantum Manager) for the middle-click scroll jump (with the left-click jump as the default)
* Wed Nov 15 2017 kill_it@mail.ru
- No space between the tab contents and a nonexistent tabbar.
* Fri Nov 10 2017 kill_it@mail.ru
- Fixed the focus rectangles of tabbar scroll buttons.
* Tue Oct 24 2017 kill_it@mail.ru
- Version 0.10.6
- Distinguish between a real tooltip and a window with the tooltip flag on unpolishing.
- Fixed the minW key with line-edits.
- Don't make a window translucent if the FramelessWindowHint or X11BypassWindowManagerHint flag is set for it after it's created but before it's polished.
- Prevent redundant flashes with focus-in/out animations.
* Tue Oct 24 2017 kill_it@mail.ru
- Put the progress text in front of the bar when progressbar_thickness is less than the text (font) height.
* Tue Sep  5 2017 kill_it@mail.ru
- Editable theme combobox in Kvantum Manager for finding installed themes by typing.
* Thu Aug 31 2017 kill_it@mail.ru
- Accept dark themes inside light theme directories.
* Mon Aug 28 2017 kill_it@mail.ru
- Optionally separate titlebar buttons for dock widgets.
- Make titlebars match the theme according to its lightness or darkness under GTK DEs like Gnome (by Craig Drummond). Now, the suffix "Dark" can have a practical meaning in the theme name.
* Fri Aug 25 2017 kill_it@mail.ru
- Separated the Qt4 code from the Qt5 one.
- Defined a few standard Qt icons.
- Fixed the size of tool buttons with just an arrow.
- A key for transparent arrow (tool) buttons.
- If the widget has no interior, check whether it has a high contrast with its container.
- Group tabbar scroll buttons together and remove their states.
* Thu Jul 20 2017 kill_it@mail.ru
- Added a key for embedded tabs, which are half embedded in their widgets.
* Tue Jul 11 2017 kill_it@mail.ru
- Added a key (to Kvantum manager) to reduce window translucency or set it in themes that don't have a translucent SVG backround for windows.
* Fri Jul  7 2017 kill_it@mail.ru
- If needed, set the window text color of menus to the normal menuitem text color because some apps may do weird things with menus.
* Fri Jun 30 2017 kill_it@mail.ru
- Set the QObject property "menu_shadow", which is a QList<int> containing left, top, right and bottom menu shadow thicknesses in that order.
* Wed Jun 28 2017 kill_it@mail.ru
- Made the combo menu (popup as menu) exactly like a menu.
- A key for removing checkboxes from combo menus.
* Tue Jun 27 2017 kill_it@mail.ru
- Compensated for menu shadows when positioning menus (thanks to Craig Drummond).
- Give viewitem top and bottom margins (frame width + text margin) to combo popup items and make their background transparent.
* Fri Jun 23 2017 kill_it@mail.ru
- Localization.
- Changed the keys "size.minwidth" and "size.minheight" to "min_width" and "min_height" respectively and added support for setting their values in terms of app font height and also as increments.
- Ability to set frame expansion in terms of app font height (for total roundness to be independent of font size).
- Suppressed GCC7 compilation warnings about "-Wimplicit-fallthrough=". (Red Hat again! Do they think people are stupid?)
- Added optional toggle and press text colors for menu(-bar) items. The fallback is focus color.
- Added a key for a 25%% translucent background for transient scrollbars.
* Mon May 29 2017 kill_it@mail.ru
- Don't let transient scrollbars overlap the frames of their views.
* Thu May 18 2017 kill_it@mail.ru
- Removed "Attached active tab..." from Kvantum Manager because it may spoil the theme.
- Added keys for scrollbar extent and toolbar grouping to Kvantum Manager.
- Ensure total transparency for the last frame of the transient scrollbar animation.
* Tue May 16 2017 kill_it@mail.ru
- Reduced the selection tint to 20%%.
- No repeating pattern for menu separators.
* Mon Apr 24 2017 kill_it@mail.ru
- Version 0.10.5
- Don't draw the groove of a transient scrollbar.
* Tue Apr 18 2017 kill_it@mail.ru
- Always center tab text (also the text position is corrected, especially for RTL).
- Added focus rectangle to all themes (also a variable is added for combo boxes without focus rectangle).
- Update the small rectangles below attached tabs (when tab rectangles are moved by tab scroll buttons). This was needed because Kvantum attaches tabs to their tab widgets in a way different from (and better than) how other style engines do.
- Added Arch PKGBUILD files (because Arch has the best way of making installable packages).
* Thu Mar 23 2017 kill_it@mail.ru
- Handle floating frames as well as windows with the ToolTip flag.
- No frame for flat groupboxes.
- Always center the tab text.
* Fri Mar 17 2017 kill_it@mail.ru
-   Multiline tab texts
    Currentlu, only Kvantum supports it.
* Sat Feb 25 2017 kill_it@mail.ru
- Don't crash on wayland (preparation for wayland).
* Mon Feb 20 2017 kill_it@mail.ru
- Don't make a window translucent if it has a stylesheet containing "background".
- Don't force window translucency when the app has a stylesheet (in contrast to widget stylesheets) because, otherwise, there would be a chance of total window transparency.
* Wed Feb  8 2017 kill_it@mail.ru
- Made x11 dragging independent of x11 (thanks to Craig).
* Sun Jan 22 2017 kill_it@mail.ru
- Added support for transient scrollbars :)
* Wed Jan 18 2017 kill_it@mail.ru
- Don't draw normal states of flat default buttons.
- A key is added (to Kvantum Manager) for not drawing window/dialog tiling patterns. As an example, an overlay pattern is added to KvCurves3d's translucent window and the key in question is used to disable
  It by default.
* Mon Jan 16 2017 kill_it@mail.ru
- Workaround for Qt5 submenu timeout bug.
* Wed Jan 11 2017 kill_it@mail.ru
- A safe, simple and elegant solution to all Qt5 translucency problems :)
* Mon Jan  9 2017 kill_it@mail.ru
- Version 0.10.4
- Better coverage of menu/tooltip translucency and/or shadow.
- Fixed the states of header arrows.
* Thu Jan  5 2017 kill_it@mail.ru
- Added a key for submenu delay (to Kvantum Manager). It can be used to show submenus only by clicking.
* Mon Dec 26 2016 kill_it@mail.ru
- Added CMake support (while qmake is kept).
- Added two keys for toolbar spacing.
* Thu Dec  8 2016 kill_it@mail.ru
- Add hover effect only selectively.
* Tue Dec  6 2016 kill_it@mail.ru
- Draw all toolbuttons auto-raised inside toolbars.
* Mon Dec  5 2016 kill_it@mail.ru
- Added a key for scrollable menus (to Kvantum Manager).
* Wed Nov 30 2016 kill_it@mail.ru
- Added a key for overlapping the active tab.
- Added a key to disable frame expansion for inactive tabs.
* Mon Nov 14 2016 kill_it@mail.ru
- Added a dark variant of KvArc (KvArcDark).
* Wed Nov  9 2016 kill_it@mail.ru
- A preliminary support for app specific themes (not documented yet).
* Wed Nov  2 2016 kill_it@mail.ru
- Added support for blurring any hard-coded translucency (and not just Konsole) with kwin.
* Mon Oct 31 2016 kill_it@mail.ru
- Support shadow for groupbox label.
* Tue Oct 25 2016 kill_it@mail.ru
- Added the hacking key no_selection_tint to Kvantum Manager.
* Wed Oct  5 2016 kill_it@mail.ru
- Added yet another toolbutton size workaround when the button text is too long.
* Thu Sep 15 2016 kill_it@mail.ru
- Version 0.10.3
- Choose the correct arrow for toolbar and menubar extension buttons. Unfortunately, the arrows can have no state other than normal and disabled (a Qt bug).
- No state other than normal is needed for toolbutton flat arrows.
* Thu Sep  1 2016 kill_it@mail.ru
- Added a theme inspired by Ubuntu's Ambiance.
- Added an optional section for styling toolbar buttons.
- Added an optional key for distinguishing between expanded and usual frames.
* Mon Aug 29 2016 kill_it@mail.ru
- Added a key for frame patterns.
- Added support for focus rectangle to comboboxes.
- Added a key to respect some DE settings (thanks to Craig).
* Thu Aug 25 2016 kill_it@mail.ru
- Global minimum width for push buttons.
- Center text+icon in push buttons.
- Added a key for layout margins (thanks to Craig).
- Support monochrome icon sets that reverse the color of selected icons.
- Added a hacking key for not tinting selected icons.
* Wed Aug 24 2016 kill_it@mail.ru
- Added a key for drawing tree branch lines (to Kvantum Manager).
- Added a key for setting the width of horizontal spin buttons (to Kvantum Manager).
* Tue Aug 23 2016 kill_it@mail.ru
- Added an Arc like theme.
* Mon Aug 22 2016 kill_it@mail.ru
- Added a key for drawing combo popups as menu popups (thanks to Craig).
- Expand x11drag option to allow finer control (thanks to Craig).
- Allow bold and italic GroupBox titles (thanks to Craig).
* Fri Aug 19 2016 kill_it@mail.ru
- Consider digiKam's DAbstractSliderSpinBox as a KisSliderSpinBox.
* Thu Aug 18 2016 kill_it@mail.ru
- Version 0.10.2
- Added a key for drawing scrollbars inside the view frame (thanks to Craig).
- Draw the background of scrollbar and scroll corner area appropriately when the scrollbar is inside the view frame.
* Tue Aug  9 2016 kill_it@mail.ru
- Just small modification to KvCurves.
- It's time for a new release.
* Mon Aug  1 2016 kill_it@mail.ru
- Don't draw the panel of a dock title button twice.
- Fixed RTL view items.
- Draw text based on its direction, not based on the layout direction.
* Mon Jul 25 2016 kill_it@mail.ru
- State change animation for line-edits and also for spin and combo boxes when they're drawn as line-edits.
- Quietened compiler warnings with Qt-5.7.
- Use "const char*" instead of "QString" wherever appropriate.
* Tue Jul 19 2016 kill_it@mail.ru
- Added a dark cyan theme.
- State change animation for line-edits and also for spin and combo boxes when they're drawn as line-edits.
* Wed Jul 13 2016 kill_it@mail.ru
- Version 0.10.1
- No label spacing for checkboxes and radiobuttons that have neither text nor icon.
* Mon Jul 11 2016 kill_it@mail.ru
- Don't force size grip on a dialog that doesn't have a layout or its layout has a size constraint of "SetFixedSize" or "SetNoConstraint".
* Fri Jul  8 2016 kill_it@mail.ru
- Added an Oxygen-like theme.
* Wed Jul  6 2016 kill_it@mail.ru
- A workaround for QtWebEngine's selection text issue.
* Tue Jul  5 2016 kill_it@mail.ru
- Draw flat pushbuttons like auto-raised toolbuttons.
* Mon Jul  4 2016 kill_it@mail.ru
- Version 0.10.0
- Added optional state change animation for buttons and non-editable comboboxes.
* Fri Jun 17 2016 kill_it@mail.ru
- Added a translucent theme.
- Also, check against the exception list without case sensitivity.
* Wed Jun  8 2016 kill_it@mail.ru
-  Added another theme to the collection.
* Mon Jun  6 2016 kill_it@mail.ru
- Version 0.9.8
- Consider QML anchoring, because of which, some widgets can't have frame expansion, tiling pattern or even interior gradient.
- No interior and frame expansion when the label of a group box is drawn on its top frame.
- Added support for expanded frame sizes.
- Remember theme specifications instead of getting theme repeatedly! This can save considerable CPU usage when a GUI is being updated quickly and continuously.
* Wed Jun  1 2016 kill_it@mail.ru
- Added a hacking key for merging PCManFM-Qt's folder-view with its surroundings (to Kvantum Manager).
- Added a dark version of KvSimplicity (KvSimplicityDark).
* Mon May 30 2016 kill_it@mail.ru
- Simplified the logic for tab separators and removed "joined_active_tab".
* Tue May 24 2016 kill_it@mail.ru
- Added a key for disabling pushbutton contents shift.
* Fri May 20 2016 kill_it@mail.ru
- Draw the focus frame around widgets with keyboard focus if it's enabled in the theme (it's disabled in the default theme).
* Thu May 19 2016 kill_it@mail.ru
- Fall back to the normal state if an object for another state isn't found.
* Wed May 18 2016 kill_it@mail.ru
- Added support for separate checkboxes and radiobuttons on menus.
* Mon May 16 2016 kill_it@mail.ru
- Version 0.9.7
- Deal with QML peculiarities.
* Thu Apr 28 2016 kill_it@mail.ru
- Added a key for always centering tabs in the document mode.
- Don't preserve permission mode when installing theme directories (Ark may give silly permissions to folders when extracting GitHub's zipped source).
* Tue Apr 19 2016 kill_it@mail.ru
-  Added a workaround for a Qt5 bug (QTBUG-47043), because of which, _NET_WM_WINDOW_TYPE is set to _NET_WM_WINDOW_TYPE_NORMAL instead of _NET_WM_WINDOW_TYPE_DROPDOWN_MENU or _NET_WM_WINDOW_TYPE_POPUP_MENU for QMenu.
* Mon Apr 11 2016 kill_it@mail.ru
- Added an experimental hacking key for setting the icon size of LXQT's main menu when it isn't styled by LXQT.
- Added "What's This?" to Kvantum Manager.
* Thu Apr  7 2016 kill_it@mail.ru
- Verion 0.9.6
- Added support for default button interior.
- Show menu titles in the toggled and not pressed state.
- Added an option for putting the group-box label above the frame.
- Removed scrollbar add-line and sub-line frame and interior.
- Add a key to join the active tab to its (inactive) adjacent tab(s). Also added support for tab separators.
- Added a key for drawing spin indicators inside the spin line-edit.
- When toobar buttons are grouped and one of the buttons is shown or hidden, update the toolbar.
- Corrections to the states of toolbuttons with menu arrow.
- Corrected blurring with HDPI because the HDPI tranlucency bug is fixed in Qt-5.6. Also tried to correct icon sizes for odd DPRs.
- Set tab horizontal and vertical spaces according to tab frame thickness (which results in an appropriate space between close button and right frame).
* Wed Mar 16 2016 kill_it@mail.ru git
- Added three extra themes (KvSimplicity, KvGnomeDark and KvFlatRed), polished some themes and modified KvDarkRed.
- At last a workaround for the Qt5 "hover bug", because of which, comboboxes and buttons remain in the mouseover state after their menus are closed and without the cursor being over them.
- Use the pressed state for focused non-editable comboboxes.
- Don't enforce darkness on text editors.
- Moved the Kvantum icon to the standard hicolor directory.
- Made the submenu overlap accurate. (As a result, a hidden mistake in the calculation of menu/tootip shadow thickness is fixed too.)
- A workaround for Qt's messy RTL submenu positioning.
* Sat Feb 20 2016 kill_it@mail.ru
- Verion 0.9.5
- Added Openbox themes for use with the included Kvantum themes (under LXQT).
- Added a new extra theme (KvSimplicity).
- Patch kvantum.pro allows build themes for openSUSE 13.1
* Wed Feb 10 2016 konstantin.voinov@gmail.com git
- Version 0.9.4
- Added a hacking key for not styling any toolbar other than the top one.
- Added a hacking key for tinting label icons on mouseover.
- Added a hacking key for setting the opacity of disabled icons.
- Draw each spinbox indicator only once.
- Draw framed spin buttons vertically if a null widget is fed into the related methods.
- Show all menu-items in the case of too big menus.
- A little overlap for submenus.
- Fixes for tabbar base panel.
- Added KvGnome, with a Gnome like look and feel, to the extra themes.
- The interior used in partial frame expansion should have the frame name.
- Workaround for bad hard-coded slider styling.
- Swap left and right text margins in RTL.
- Added a general key for submenu overlap with -1 (automatic) as default.
- Take frame vertical asymmetry into account when drawing labels of push buttons and comboboxes.
* Tue Dec 22 2015 konstantin.voinov@gmail.com git
- Version 0.9.3
- Support high DPI displays (when QT_DEVICE_PIXEL_RATIO > 1 and even when AA_UseHighDpiPixmaps isn't set).
- Draw subwindow titlebar buttons on menubars exactly as on MDI titlebars.
- Added a hacking key for not styling any toolbar other than the top one.
- Calculate the height of problematic fonts like Noto Sans correctly.
- Corrected a typo in SE_TabWidgetRightCorner.
- Force progressbar roundness on KCapacityBar in all circumstances.
- Always show text in KisSliderSpinBox.
- Removed the redundant key "textless_progressbar".
- Group toolbar buttons based on their heights (not their iconlessness).
* Wed Nov 25 2015 konstantin.voinov@gmail.com git
- Version 0.9.2
- Added '$DATADIR/themes/$THEME_NAME/Kvantum/', '~/.themes/$THEME_NAME/Kvantum/' and '~/.local/share/themes/$THEME_NAME/Kvantum/' to the installation paths but with lower priority (the second directory ha
- Added a hacking key for not using bold font for the text of a default push button.
- Added a general key for layout spacing, with a value between 2 and 10px.
- Added another extra theme (KvCurves3d).
- Used a more reliable boolean for determining whether a slider is horizontal.
- Support the #RRGGBBAA format for color names.
- Use the combobox indicator element if its normal state exists.
- Respect darkness only when the window color is dark enough.
- Don't group toolbar buttons on a vertical toolbar because they wouldn't look elegant, especially with frame expansion.
- Don't rotate toolbar buttons by 90 degrees on a vertical toolbar.
* Thu Nov 12 2015 konstantin.voinov@gmail.com git
- A workaround for the rare occasion when the background of a Qt5 composited tooltip is filled by the window background color.
- In the case of menus and tooltips, check compositing at the moment of their creaton (this fixes shadowless menus of KF5 desktop and panel).
- Always show text in KCapacityBar.
- Added a general key for setting tooltip display delay.
- Consider the possibility of color gradients in the case of view-items with hard-coded backgrounds when setting their texts.
- Gave priority to the new location of kdeglobals.
* Thu Oct  1 2015 konstantin.voinov@gmail.com git
- Added two extra themes (KvDarkRed and KvBeige).
- Minor modifications to Kvantum Manager (to recognize KF5 and LXQT more).
* Tue Aug 25 2015 konstantin.voinov@gmail.com git
- Move ChangeLog COPYING NEWS README to main package.
- Use the generic frame for combo menus.
- Added a key for drawing editable comboboxes as lineedits.
- Use the generic frame for combo menus.
- Check iconlessness when grouping toolbar buttons.
- Added a hacking key for merging PCManFM-qt's sidepane with its surroundings (to Kvantum Manager).
- It's time to have a decent icon for Kvantum.
* Mon Aug 24 2015 konstantin.voinov@gmail.com git
- Version 0.8.25
- Added a key for drawing editable comboboxes as lineedits.
- V0.8.24
- Added some of my themes, that don't need special titlebars, to the project for Kvantum to have extra themes by default. They're installed as root with Qt5 installation.
- Fixed Kvantum Managers's comment tooltip for root themes.
- Fixed a miscalculation when the text has shadow.
- Took care of buttonless spinboxes.
- Don't move the cursor out of the window and back for x11 dragging with Qt5. This workaround not only isn't needed anymore but also creates artifacts with Openbox.
* Fri Aug 14 2015 konstantin.voinov@gmail.com git
- Version 0.8.24
- Added some of my themes, that don't need special titlebars, to the project for Kvantum to have extra themes by default. They're installed as root with Qt5 installation.
- Fixed Kvantum Managers's comment tooltip for root themes.
* Mon Jul 13 2015 konstantin.voinov@gmail.com git
- Version 0.8.23
- Added two new sections for opaque and translucent dialogs. The fallbacks are the sections "WindowTranslucent" and "Window".
- Added KF5 system and user color scheme paths to "style.pro" and "KvantumManager.cpp", respectively. The system path is used with the Qt5 compilation.
- Added a hacking key for removing the icons of pushbuttons as far as possible.
- Another hacking key for removing menu icons.
- A lot of subtle changes that together guarantee a more logical look under unusual circumstances.
- Corrected some miscalculations.
- When calculating spinbox size, consider the case where only QAbstractSpinBox is subclassed.
- Fixed a compilation error with Qt5-5.5.0.
- Took care of textless menuitems.
- Forced KCalcDisplay's text color.
- Let the size grip be just an indicator and added one to the default theme.
- Draw the size grip relative to the corner.
- Don't allow windows to have custom background colors if they have different window and base colors. As for their text color, it's the responsibility of developers to use QStyle correctly.
- Another criterion for giving shadow/translucency to menus.
- Changed the toggled and pressed buttons of the default theme.
- To get the spinbox maximum-length text, use the real width of the text, not the number of its characters.
- Version 0.8.22
- Added an experimental hacking key to force size grips of dialogs and statusbars.
- Partially rounded view-items (in some places) and headers.
- How did I forget namespace in such a program?!
- Take care of transparent line-edits in comboboxes (I've seen them only in Qt5 Cantata).
- Added a key for the minimum scrollbar extent and gave a 1px space to scrollbars of very thin widgets.
- Set lower/upper limits for some integer keys.
- If "mirror_doc_tabs" is false, don't mirror tabs when "attach_active_tab" is also false.
* Tue Jul  7 2015 konstantin.voinov@gmail.com git
- Version 0.8.21
- If the interior element of the "expand-" objects exists, make borders rounded even when the widget height is greater than the value of frame expansion.
- Now it's possible to have clean borders with maximally rounded corners (without a new key and when the "border-" elements exist).
- Added a configuration section for distinguishing between opaque and translucent window backgrounds if needed.
- Added a key for not mirroring the top/left tab shape to draw the bottom/right tab in the document mode.
- Set the pressed state for a combobox if its line-edit has focus.
- Compile kvantumpreview and kventummanager against Qt5 by default.
- Workaround for the nasty behavior of Qt5 QSettings, which reorders keys on writing.
- A little more space for centered toolbar handles.
- Added a hacking key to force size grips of dialogs and statusbars.
* Wed Mar  4 2015 konstantin.voinov@gmail.com git
- first line at changelog
